@@ -73,9 +73,13 @@ class Chord(object):
 
     def shiftable(self):
         result = False not in [ x.shiftable() for x in self.notes ]
-        print("CHORD SHIFT: %s" % result)
         return result
 
+    def has_repeats(self):
+        for x in self.notes:
+            if x.repeat:
+                return True
+        return False
 
     def chordify(self, chord_type):
         """
