@@ -7,7 +7,7 @@
 # a device represents a physical or virtual MIDI interface
 
 from .base import NewReferenceObject
-import mido
+from warpseq.playback.midi import open_port
 
 class Device(NewReferenceObject):
 
@@ -19,13 +19,9 @@ class Device(NewReferenceObject):
         self._midi_out = None
         super(Device,self).__init__()
 
-
     def get_midi_out(self):
         if self._midi_out is None:
-            try:
-                self._midi_out = mido.open_output(self.name) # self.midi_port)
-            except OSError:
-                raise MIDIConfigError("MIDI device named (%s) not found, available choices: %s" % (self.device.name, ports))
+            self._midi_out = open_port(self.name)
         return self._midi_out
 
     def to_dict(self):
